import React, { useEffect, useState } from 'react';
import { generateResponse } from '@/services/geminiService';

interface DynamicContentProps {
  content: any;
}

const DynamicContent: React.FC<DynamicContentProps> = ({ content }) => {
  const [geminiAnswer, setGeminiAnswer] = useState<string | null>(null);
  const [loading, setLoading] = useState(false);

  useEffect(() => {
    const fetchGemini = async () => {
      if (content?.type === 'gemini' && content.prompt) {
        setLoading(true);
        const res = await generateResponse(content.prompt);
        setGeminiAnswer(res);
        setLoading(false);
      }
    };
    fetchGemini();
  }, [content]);

  if (!content) return null;

  if (content.type === 'gemini') {
    return (
      <div className="p-6">
        <h3 className="text-lg font-semibold mb-4">Gemini Answer</h3>
        {loading ? (
          <div className="text-gray-500">Loading...</div>
        ) : (
          <div className="text-gray-900 dark:text-white whitespace-pre-line">{geminiAnswer}</div>
        )}
      </div>
    );
  }

  // If content is a React node/component, render it
  if (React.isValidElement(content)) return content;

  // Fallback: render as text
  return (
    <div className="p-6 text-gray-900 dark:text-white">
      {typeof content === 'string' ? content : JSON.stringify(content)}
    </div>
  );
};

export default DynamicContent;


// This would generate proper html jsx codes but it requires more advanced models

// import React, { useEffect, useState } from 'react';
// import { generateResponse } from '@/services/geminiService';

// interface DynamicContentProps {
//   content: any;
// }

// const DynamicContent: React.FC<DynamicContentProps> = ({ content }) => {
//   const [geminiAnswer, setGeminiAnswer] = useState<string | null>(null);
//   const [loading, setLoading] = useState(false);

//   useEffect(() => {
//     const fetchGemini = async () => {
//       if (content?.type === 'gemini' && content.prompt) {
//         setLoading(true);
//         try {
//           const formattedPrompt = `
// You are an AI that outputs JSX for Tailwind-styled UI components.

// Task:
// - Return a single JSX <div> component with className="space-y-8"
// - Include a title section with heading and paragraph
// - Include 3 hardcoded MCP cards inside a grid layout
// - Each card must include: name, description, 3 features in <li>, and author
// - Use Tailwind CSS classes as shown in the example

// ⚠️ Output ONLY JSX — no explanations, no markdown, no \`\`\`jsx

// Example format:

// <div className="space-y-8">
//   <div className="space-y-4">
//     <h3 className="text-xl font-semibold text-gray-900 dark:text-white">
//       Sample MCP Servers
//     </h3>
//     <p className="text-gray-600 dark:text-gray-300 leading-relaxed">
//       Explore a few example MCPs you can build, deploy, and monetize on the Fastcode platform.
//     </p>
//   </div>

//   <div className="grid gap-6 md:grid-cols-2">
//     <div className="flex flex-col gap-3 p-6 rounded-2xl border border-gray-200/20 dark:border-gray-700/20 backdrop-blur-sm bg-white/5 dark:bg-black/5 hover:scale-105 transition-all duration-300">
//       <div className="flex items-center gap-3">
//         <h4 className="font-medium text-gray-900 dark:text-white">Image Enhancer</h4>
//       </div>
//       <div className="text-sm text-gray-600 dark:text-gray-300">Enhance image quality with AI.</div>
//       <ul className="list-disc list-inside text-xs text-gray-500 dark:text-gray-400 pl-2">
//         <li>Upscale resolution</li>
//         <li>Reduce noise</li>
//         <li>Sharpen details</li>
//       </ul>
//       <div className="text-xs text-gray-400 dark:text-gray-500 mt-2">By fastcoder.ai</div>
//     </div>

//     <!-- More cards -->
//   </div>
// </div>
// `;


//           const res = await generateResponse(formattedPrompt.trim());
//           setGeminiAnswer(res);
//         } catch (error) {
//           setGeminiAnswer("Something went wrong while generating the response.");
//         } finally {
//           setLoading(false);
//         }
//       }
//     };
//     fetchGemini();
//   }, [content]);

//   if (!content) return null;

//   if (content.type === 'gemini') {
//     return (
//       <div className="p-6">
//         <h3 className="text-lg font-semibold mb-4">Gemini Answer</h3>
//         {loading ? (
//           <div className="text-gray-500">Loading...</div>
//         ) : (
//           <div
//             className="text-gray-900 dark:text-white"
//             dangerouslySetInnerHTML={{ __html: geminiAnswer || '' }}
//           />
//         )}
//       </div>
//     );
//   }

//   if (React.isValidElement(content)) return content;

//   return (
//     <div className="p-6 text-gray-900 dark:text-white">
//       {typeof content === 'string' ? content : JSON.stringify(content)}
//     </div>
//   );
// };

// export default DynamicContent;
