import { GoogleGenerativeAI } from '@google/generative-ai';

const GEMINI_API_KEY= 'AIzaSyAK8AyA8JYTprpqIif4qBiPql84Uh0VFh4';

// Initialize the Gemini API with your API key
const genAI = new GoogleGenerativeAI(GEMINI_API_KEY || '');

const SYSTEM_PROMPT = `
You are an AI assistant for a platform that helps users discover and use MCPs (Monetizable Code Packages).

- Developers can create and monetize MCPs by wrapping AI functionality into deployable, market-ready APIs.
- Non-developers can use a no-code tool to build and publish their own MCPs.
- Users interact with these MCPs through a smart chat interface, selecting the ones they want and getting tasks done directly inside the chat.
- Your job is to guide users in understanding and using the platform.

Always respond:
- In friendly, simple language
- In plain text (no markdown or formatting)
- In a single paragraph under 50 words
- Without repeating or rephrasing the user's question
`;


const GEMINI_URL = 'https://generativelanguage.googleapis.com/v1beta/models/gemini-pro:generateContent';

export async function generateResponse(prompt: string): Promise<string> {
  const model = genAI.getGenerativeModel({ model: 'gemini-2.0-flash' });

  const result = await model.generateContent({
    contents: [
      {
        role: 'user',
        parts: [{ text: `${SYSTEM_PROMPT}\n\nUser: ${prompt}` }],
      },
    ],
  });

  const response = await result.response;
  const text = response.text();
  return text || "I'm not sure about that.";
}

// export const generateResponse = async (prompt: string, chatHistory: Array<{role: 'user' | 'model', parts: string}>) => {
//   try {
//     // Get the Gemini Pro model
//     const model = genAI.getGenerativeModel({ model: 'gemini-pro' });
    
//     // Format chat history for the API
//     const chat = model.startChat({
//       history: [
//         {
//           role: 'user',
//           parts: [{ text: SYSTEM_PROMPT }],
//         },
//         {
//           role: 'model',
//           parts: [{ text: 'I understand. I will follow these guidelines when responding to questions, especially when I don\'t have complete information.' }],
//         },
//         ...chatHistory.map(msg => ({
//           role: msg.role === 'user' ? 'user' : 'model',
//           parts: [{ text: msg.parts }],
//         })),
//       ],
//       generationConfig: {
//         maxOutputTokens: 1000,
//         temperature: 0.7,
//       },
//     });

//     // Send the message and get the response
//     const result = await chat.sendMessage(prompt);
//     const response = await result.response;
//     const text = response.text();
    
//     return {
//       success: true,
//       message: text,
//     };
//   } catch (error) {
//     console.error('Error generating response:', error);
//     return {
//       success: false,
//       message: 'Sorry, I encountered an error while processing your request. Please try again later.'
//     };
//   }
// };

// export const isQuestionUnknown = (response: string): boolean => {
//   // Simple check for phrases that might indicate the model doesn't know the answer
//   const unknownPhrases = [
//     'i don\'t know',
//     'i\'m not sure',
//     'i don\'t have that information',
//     'i don\'t have specific information',
//     'i don\'t have access to',
//     'i don\'t have the capability',
//     'i don\'t have enough information',
//     'i can\'t provide',
//     'i\'m unable to',
//     'i don\'t have the ability',
//   ];

//   return unknownPhrases.some(phrase => 
//     response.toLowerCase().includes(phrase)
//   );
// };
